==> aws-cdk-scala-lightsail_3-0.3.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"lightsail","t":"lightsail","d":"","k":"static"},
{"l":"io/burkard/cdk/services/lightsail.html","n":"io.burkard.cdk.services.lightsail","t":"package io.burkard.cdk.services.lightsail","d":"io/burkard/cdk/services/lightsail","k":"package"},
{"l":"io/burkard/cdk/services/lightsail/AddOnProperty$.html","n":"AddOnProperty","t":"object AddOnProperty","d":"io/burkard/cdk/services/lightsail/AddOnProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/AddOnProperty$.html","n":"apply","t":"def apply(addOnType: String, autoSnapshotAddOnRequest: Option[AutoSnapshotAddOnProperty], status: Option[String]): AddOnProperty","d":"io/burkard/cdk/services/lightsail/AddOnProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$.html","n":"AutoSnapshotAddOnProperty","t":"object AutoSnapshotAddOnProperty","d":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$.html","n":"apply","t":"def apply(snapshotTimeOfDay: Option[String]): AutoSnapshotAddOnProperty","d":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabase$.html","n":"CfnDatabase","t":"object CfnDatabase","d":"io/burkard/cdk/services/lightsail/CfnDatabase$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabase$.html","n":"apply","t":"def apply(internalResourceId: String, masterDatabaseName: String, relationalDatabaseBlueprintId: String, relationalDatabaseBundleId: String, relationalDatabaseName: String, masterUsername: String, backupRetention: Option[Boolean], rotateMasterUserPassword: Option[Boolean], availabilityZone: Option[String], relationalDatabaseParameters: Option[List[_]], publiclyAccessible: Option[Boolean], masterUserPassword: Option[String], tags: Option[List[_ <: CfnTag]], caCertificateIdentifier: Option[String], preferredMaintenanceWindow: Option[String], preferredBackupWindow: Option[String])(implicit stackCtx: Stack): CfnDatabase","d":"io/burkard/cdk/services/lightsail/CfnDatabase$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$.html","n":"CfnDatabaseProps","t":"object CfnDatabaseProps","d":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$.html","n":"apply","t":"def apply(masterDatabaseName: String, relationalDatabaseBlueprintId: String, relationalDatabaseBundleId: String, relationalDatabaseName: String, masterUsername: String, backupRetention: Option[Boolean], rotateMasterUserPassword: Option[Boolean], availabilityZone: Option[String], relationalDatabaseParameters: Option[List[_]], publiclyAccessible: Option[Boolean], masterUserPassword: Option[String], tags: Option[List[_ <: CfnTag]], caCertificateIdentifier: Option[String], preferredMaintenanceWindow: Option[String], preferredBackupWindow: Option[String]): CfnDatabaseProps","d":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDisk$.html","n":"CfnDisk","t":"object CfnDisk","d":"io/burkard/cdk/services/lightsail/CfnDisk$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDisk$.html","n":"apply","t":"def apply(internalResourceId: String, sizeInGb: Number, diskName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], availabilityZone: Option[String])(implicit stackCtx: Stack): CfnDisk","d":"io/burkard/cdk/services/lightsail/CfnDisk$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDiskProps$.html","n":"CfnDiskProps","t":"object CfnDiskProps","d":"io/burkard/cdk/services/lightsail/CfnDiskProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDiskProps$.html","n":"apply","t":"def apply(sizeInGb: Number, diskName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], availabilityZone: Option[String]): CfnDiskProps","d":"io/burkard/cdk/services/lightsail/CfnDiskProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstance$.html","n":"CfnInstance","t":"object CfnInstance","d":"io/burkard/cdk/services/lightsail/CfnInstance$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstance$.html","n":"apply","t":"def apply(internalResourceId: String, bundleId: String, blueprintId: String, instanceName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], userData: Option[String], hardware: Option[HardwareProperty], keyPairName: Option[String], availabilityZone: Option[String], networking: Option[NetworkingProperty])(implicit stackCtx: Stack): CfnInstance","d":"io/burkard/cdk/services/lightsail/CfnInstance$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstanceProps$.html","n":"CfnInstanceProps","t":"object CfnInstanceProps","d":"io/burkard/cdk/services/lightsail/CfnInstanceProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstanceProps$.html","n":"apply","t":"def apply(bundleId: String, blueprintId: String, instanceName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], userData: Option[String], hardware: Option[HardwareProperty], keyPairName: Option[String], availabilityZone: Option[String], networking: Option[NetworkingProperty]): CfnInstanceProps","d":"io/burkard/cdk/services/lightsail/CfnInstanceProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIp$.html","n":"CfnStaticIp","t":"object CfnStaticIp","d":"io/burkard/cdk/services/lightsail/CfnStaticIp$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIp$.html","n":"apply","t":"def apply(internalResourceId: String, staticIpName: String, attachedTo: Option[String])(implicit stackCtx: Stack): CfnStaticIp","d":"io/burkard/cdk/services/lightsail/CfnStaticIp$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$.html","n":"CfnStaticIpProps","t":"object CfnStaticIpProps","d":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$.html","n":"apply","t":"def apply(staticIpName: String, attachedTo: Option[String]): CfnStaticIpProps","d":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/DiskProperty$.html","n":"DiskProperty","t":"object DiskProperty","d":"io/burkard/cdk/services/lightsail/DiskProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/DiskProperty$.html","n":"apply","t":"def apply(path: String, diskName: String, attachedTo: Option[String], attachmentState: Option[String], isSystemDisk: Option[Boolean], iops: Option[Number], sizeInGb: Option[String]): DiskProperty","d":"io/burkard/cdk/services/lightsail/DiskProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/HardwareProperty$.html","n":"HardwareProperty","t":"object HardwareProperty","d":"io/burkard/cdk/services/lightsail/HardwareProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/HardwareProperty$.html","n":"apply","t":"def apply(cpuCount: Option[Number], disks: Option[List[_]], ramSizeInGb: Option[Number]): HardwareProperty","d":"io/burkard/cdk/services/lightsail/HardwareProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/LocationProperty$.html","n":"LocationProperty","t":"object LocationProperty","d":"io/burkard/cdk/services/lightsail/LocationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/LocationProperty$.html","n":"apply","t":"def apply(availabilityZone: Option[String], regionName: Option[String]): LocationProperty","d":"io/burkard/cdk/services/lightsail/LocationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$.html","n":"MonthlyTransferProperty","t":"object MonthlyTransferProperty","d":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$.html","n":"apply","t":"def apply(gbPerMonthAllocated: Option[String]): MonthlyTransferProperty","d":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/NetworkingProperty$.html","n":"NetworkingProperty","t":"object NetworkingProperty","d":"io/burkard/cdk/services/lightsail/NetworkingProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/NetworkingProperty$.html","n":"apply","t":"def apply(ports: List[_], monthlyTransfer: Option[Number]): NetworkingProperty","d":"io/burkard/cdk/services/lightsail/NetworkingProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/PortProperty$.html","n":"PortProperty","t":"object PortProperty","d":"io/burkard/cdk/services/lightsail/PortProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/PortProperty$.html","n":"apply","t":"def apply(accessType: Option[String], cidrListAliases: Option[List[String]], toPort: Option[Number], commonName: Option[String], cidrs: Option[List[String]], accessFrom: Option[String], fromPort: Option[Number], accessDirection: Option[String], ipv6Cidrs: Option[List[String]], protocol: Option[String]): PortProperty","d":"io/burkard/cdk/services/lightsail/PortProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$.html","n":"RelationalDatabaseParameterProperty","t":"object RelationalDatabaseParameterProperty","d":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$.html","n":"apply","t":"def apply(applyType: Option[String], isModifiable: Option[Boolean], parameterValue: Option[String], parameterName: Option[String], description: Option[String], allowedValues: Option[String], dataType: Option[String], applyMethod: Option[String]): RelationalDatabaseParameterProperty","d":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/StateProperty$.html","n":"StateProperty","t":"object StateProperty","d":"io/burkard/cdk/services/lightsail/StateProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/StateProperty$.html","n":"apply","t":"def apply(name: Option[String], code: Option[Number]): StateProperty","d":"io/burkard/cdk/services/lightsail/StateProperty$","k":"def"},
{"l":"docs/index.html","n":"lightsail","t":"lightsail","d":"","k":"static"}];

==> aws-cdk-scala-lightsail_3-0.4.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"lightsail","t":"lightsail","d":"","k":"static"},
{"l":"io/burkard/cdk/services/lightsail.html","n":"io.burkard.cdk.services.lightsail","t":"package io.burkard.cdk.services.lightsail","d":"io/burkard/cdk/services/lightsail","k":"package"},
{"l":"io/burkard/cdk/services/lightsail/AddOnProperty$.html","n":"AddOnProperty","t":"object AddOnProperty","d":"io/burkard/cdk/services/lightsail/AddOnProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/AddOnProperty$.html","n":"apply","t":"def apply(addOnType: String, status: Option[String], autoSnapshotAddOnRequest: Option[AutoSnapshotAddOnProperty]): AddOnProperty","d":"io/burkard/cdk/services/lightsail/AddOnProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$.html","n":"AutoSnapshotAddOnProperty","t":"object AutoSnapshotAddOnProperty","d":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$.html","n":"apply","t":"def apply(snapshotTimeOfDay: Option[String]): AutoSnapshotAddOnProperty","d":"io/burkard/cdk/services/lightsail/AutoSnapshotAddOnProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabase$.html","n":"CfnDatabase","t":"object CfnDatabase","d":"io/burkard/cdk/services/lightsail/CfnDatabase$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabase$.html","n":"apply","t":"def apply(internalResourceId: String, masterDatabaseName: String, relationalDatabaseBlueprintId: String, masterUsername: String, relationalDatabaseBundleId: String, relationalDatabaseName: String, backupRetention: Option[Boolean], masterUserPassword: Option[String], tags: Option[List[_ <: CfnTag]], rotateMasterUserPassword: Option[Boolean], availabilityZone: Option[String], caCertificateIdentifier: Option[String], preferredMaintenanceWindow: Option[String], relationalDatabaseParameters: Option[List[_]], publiclyAccessible: Option[Boolean], preferredBackupWindow: Option[String])(implicit stackCtx: Stack): CfnDatabase","d":"io/burkard/cdk/services/lightsail/CfnDatabase$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$.html","n":"CfnDatabaseProps","t":"object CfnDatabaseProps","d":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$.html","n":"apply","t":"def apply(masterDatabaseName: String, relationalDatabaseBlueprintId: String, masterUsername: String, relationalDatabaseBundleId: String, relationalDatabaseName: String, backupRetention: Option[Boolean], masterUserPassword: Option[String], tags: Option[List[_ <: CfnTag]], rotateMasterUserPassword: Option[Boolean], availabilityZone: Option[String], caCertificateIdentifier: Option[String], preferredMaintenanceWindow: Option[String], relationalDatabaseParameters: Option[List[_]], publiclyAccessible: Option[Boolean], preferredBackupWindow: Option[String]): CfnDatabaseProps","d":"io/burkard/cdk/services/lightsail/CfnDatabaseProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDisk$.html","n":"CfnDisk","t":"object CfnDisk","d":"io/burkard/cdk/services/lightsail/CfnDisk$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDisk$.html","n":"apply","t":"def apply(internalResourceId: String, sizeInGb: Number, diskName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], availabilityZone: Option[String])(implicit stackCtx: Stack): CfnDisk","d":"io/burkard/cdk/services/lightsail/CfnDisk$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnDiskProps$.html","n":"CfnDiskProps","t":"object CfnDiskProps","d":"io/burkard/cdk/services/lightsail/CfnDiskProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnDiskProps$.html","n":"apply","t":"def apply(sizeInGb: Number, diskName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], availabilityZone: Option[String]): CfnDiskProps","d":"io/burkard/cdk/services/lightsail/CfnDiskProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstance$.html","n":"CfnInstance","t":"object CfnInstance","d":"io/burkard/cdk/services/lightsail/CfnInstance$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstance$.html","n":"apply","t":"def apply(internalResourceId: String, bundleId: String, blueprintId: String, instanceName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], userData: Option[String], availabilityZone: Option[String], networking: Option[NetworkingProperty], hardware: Option[HardwareProperty], keyPairName: Option[String])(implicit stackCtx: Stack): CfnInstance","d":"io/burkard/cdk/services/lightsail/CfnInstance$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstanceProps$.html","n":"CfnInstanceProps","t":"object CfnInstanceProps","d":"io/burkard/cdk/services/lightsail/CfnInstanceProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnInstanceProps$.html","n":"apply","t":"def apply(bundleId: String, blueprintId: String, instanceName: String, addOns: Option[List[_]], tags: Option[List[_ <: CfnTag]], userData: Option[String], availabilityZone: Option[String], networking: Option[NetworkingProperty], hardware: Option[HardwareProperty], keyPairName: Option[String]): CfnInstanceProps","d":"io/burkard/cdk/services/lightsail/CfnInstanceProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIp$.html","n":"CfnStaticIp","t":"object CfnStaticIp","d":"io/burkard/cdk/services/lightsail/CfnStaticIp$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIp$.html","n":"apply","t":"def apply(internalResourceId: String, staticIpName: String, attachedTo: Option[String])(implicit stackCtx: Stack): CfnStaticIp","d":"io/burkard/cdk/services/lightsail/CfnStaticIp$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$.html","n":"CfnStaticIpProps","t":"object CfnStaticIpProps","d":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$.html","n":"apply","t":"def apply(staticIpName: String, attachedTo: Option[String]): CfnStaticIpProps","d":"io/burkard/cdk/services/lightsail/CfnStaticIpProps$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/DiskProperty$.html","n":"DiskProperty","t":"object DiskProperty","d":"io/burkard/cdk/services/lightsail/DiskProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/DiskProperty$.html","n":"apply","t":"def apply(path: String, diskName: String, attachedTo: Option[String], attachmentState: Option[String], isSystemDisk: Option[Boolean], iops: Option[Number], sizeInGb: Option[String]): DiskProperty","d":"io/burkard/cdk/services/lightsail/DiskProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/HardwareProperty$.html","n":"HardwareProperty","t":"object HardwareProperty","d":"io/burkard/cdk/services/lightsail/HardwareProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/HardwareProperty$.html","n":"apply","t":"def apply(cpuCount: Option[Number], disks: Option[List[_]], ramSizeInGb: Option[Number]): HardwareProperty","d":"io/burkard/cdk/services/lightsail/HardwareProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/LocationProperty$.html","n":"LocationProperty","t":"object LocationProperty","d":"io/burkard/cdk/services/lightsail/LocationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/LocationProperty$.html","n":"apply","t":"def apply(availabilityZone: Option[String], regionName: Option[String]): LocationProperty","d":"io/burkard/cdk/services/lightsail/LocationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$.html","n":"MonthlyTransferProperty","t":"object MonthlyTransferProperty","d":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$.html","n":"apply","t":"def apply(gbPerMonthAllocated: Option[String]): MonthlyTransferProperty","d":"io/burkard/cdk/services/lightsail/MonthlyTransferProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/NetworkingProperty$.html","n":"NetworkingProperty","t":"object NetworkingProperty","d":"io/burkard/cdk/services/lightsail/NetworkingProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/NetworkingProperty$.html","n":"apply","t":"def apply(ports: List[_], monthlyTransfer: Option[Number]): NetworkingProperty","d":"io/burkard/cdk/services/lightsail/NetworkingProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/PortProperty$.html","n":"PortProperty","t":"object PortProperty","d":"io/burkard/cdk/services/lightsail/PortProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/PortProperty$.html","n":"apply","t":"def apply(accessType: Option[String], cidrListAliases: Option[List[String]], toPort: Option[Number], commonName: Option[String], cidrs: Option[List[String]], accessFrom: Option[String], fromPort: Option[Number], accessDirection: Option[String], ipv6Cidrs: Option[List[String]], protocol: Option[String]): PortProperty","d":"io/burkard/cdk/services/lightsail/PortProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$.html","n":"RelationalDatabaseParameterProperty","t":"object RelationalDatabaseParameterProperty","d":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$.html","n":"apply","t":"def apply(applyType: Option[String], description: Option[String], allowedValues: Option[String], isModifiable: Option[Boolean], parameterValue: Option[String], parameterName: Option[String], dataType: Option[String], applyMethod: Option[String]): RelationalDatabaseParameterProperty","d":"io/burkard/cdk/services/lightsail/RelationalDatabaseParameterProperty$","k":"def"},
{"l":"io/burkard/cdk/services/lightsail/StateProperty$.html","n":"StateProperty","t":"object StateProperty","d":"io/burkard/cdk/services/lightsail/StateProperty$","k":"object"},
{"l":"io/burkard/cdk/services/lightsail/StateProperty$.html","n":"apply","t":"def apply(name: Option[String], code: Option[Number]): StateProperty","d":"io/burkard/cdk/services/lightsail/StateProperty$","k":"def"},
{"l":"docs/index.html","n":"lightsail","t":"lightsail","d":"","k":"static"}];
